@@ -8,7 +8,7 @@ use Date::Calc qw(Add_Delta_Days
                   Nth_Weekday_of_Month_Year
                   check_date check_time);
 
-our $VERSION = '1.12';
+our $VERSION = '1.14';
 
 use constant MORNING   => '08';
 use constant AFTERNOON => '14';
@@ -795,6 +795,20 @@ sub _count_weekday
     $self->_set_modified(2);
 }
 
+sub _day_month_year
+{
+    my $self = shift;
+    $self->_add_trace;
+    my ($day, $month, $year) = @_;
+    $self->_month_name(\$month);
+    $self->{datetime}->set(
+        year => $year,
+        month => $self->_month_num($month),
+        day => $day,
+    );
+    $self->_set_modified(3);
+}
+
 sub _day_name
 {
     my $self = shift;
@@ -903,7 +917,7 @@ DateTime::Format::Natural::Base - Base class for DateTime::Format::Natural
 
 =head1 DESCRIPTION
 
-The C<DateTime::Format::Natural::Base> module defines the core functionality of
+The C<DateTime::Format::Natural::Base> class defines the core functionality of
 C<DateTime::Format::Natural>.
 
 =head1 SEE ALSO
